@@ -24,16 +24,21 @@ func (l AWSNeptuneDbSubnetGroup) List(ctx context.AWSetsCtx) (*resource.Group, e
 	svc := neptune.NewFromConfig(ctx.AWSCfg)
 
 	rg := resource.NewGroup()
-	err := Paginator(func(nt *string) (*string, error) {
-		res, err := svc.DescribeDBSubnetGroups(ctx.Context, &neptune.DescribeDBSubnetGroupsInput{
-			MaxRecords: aws.Int32(100),
-			Marker:     nt,
-		})
+
+	paginator := neptune.NewDescribeDBSubnetGroupsPaginator(svc, &neptune.DescribeDBSubnetGroupsInput{
+		MaxRecords: aws.Int32(100),
+	})
+
+	for paginator.HasMorePages() {
+		page, err := paginator.NextPage(ctx.Context)
 		if err != nil {
 			return nil, err
 		}
-		for _, v := range res.DBSubnetGroups {
+		for _, v := range page.DBSubnetGroups {
 			subnetArn := arn.ParseP(v.DBSubnetGroupArn)
+			if subnetArn.Service != "neptune" {
+				continue
+			}
 			r := resource.New(ctx, resource.NeptuneDbSubnetGroup, subnetArn.ResourceId, "", v)
 			r.AddRelation(resource.Ec2Vpc, v.VpcId, "")
 			for _, subnet := range v.Subnets {
@@ -41,7 +46,6 @@ func (l AWSNeptuneDbSubnetGroup) List(ctx context.AWSetsCtx) (*resource.Group, e
 			}
 			rg.AddResource(r)
 		}
-		return res.Marker, nil
-	})
-	return rg, err
+	}
+	return rg, nil
 }
