@@ -11,12 +11,17 @@ var mapping = map[string]ResourceType{
 	"AWS::ACMPCA::Certificate":                                    Unmapped,
 	"AWS::ACMPCA::CertificateAuthority":                           Unmapped,
 	"AWS::ACMPCA::CertificateAuthorityActivation":                 Unmapped,
+	"AWS::ACMPCA::Permission":                                     Unmapped,
+	"AWS::APS::RuleGroupsNamespace":                               Unmapped,
+	"AWS::APS::Workspace":                                         Unmapped,
 	"AWS::AmazonMQ::Broker":                                       AmazonMQBroker,
 	"AWS::AmazonMQ::Configuration":                                AmazonMQBrokerConfiguration,
 	"AWS::AmazonMQ::ConfigurationAssociation":                     AmazonMQBroker,
 	"AWS::Amplify::App":                                           AmplifyApp,
 	"AWS::Amplify::Branch":                                        AmplifyBranch,
 	"AWS::Amplify::Domain":                                        AmplifyDomain,
+	"AWS::AmplifyUIBuilder::Component":                            Unmapped,
+	"AWS::AmplifyUIBuilder::Theme":                                Unmapped,
 	"AWS::ApiGateway::Account":                                    Unmapped,
 	"AWS::ApiGateway::ApiKey":                                     ApiGatewayApiKey,
 	"AWS::ApiGateway::Authorizer":                                 ApiGatewayAuthorizer,
@@ -66,6 +71,9 @@ var mapping = map[string]ResourceType{
 	"AWS::AppMesh::VirtualRouter":                                 AppMeshVirtualRouter,
 	"AWS::AppMesh::VirtualService":                                AppMeshVirtualService,
 	"AWS::AppRunner::Service":                                     Unmapped,
+	"AWS::AppStream::AppBlock":                                    Unmapped,
+	"AWS::AppStream::Application":                                 Unmapped,
+	"AWS::AppStream::ApplicationFleetAssociation":                 Unmapped,
 	"AWS::AppStream::DirectoryConfig":                             Unmapped,
 	"AWS::AppStream::Fleet":                                       Unmapped,
 	"AWS::AppStream::ImageBuilder":                                Unmapped,
@@ -76,6 +84,8 @@ var mapping = map[string]ResourceType{
 	"AWS::AppSync::ApiCache":                                      AppSyncApiCache,
 	"AWS::AppSync::ApiKey":                                        AppSyncApiKey,
 	"AWS::AppSync::DataSource":                                    AppSyncDataSource,
+	"AWS::AppSync::DomainName":                                    Unmapped,
+	"AWS::AppSync::DomainNameApiAssociation":                      Unmapped,
 	"AWS::AppSync::FunctionConfiguration":                         AppSyncFunction,
 	"AWS::AppSync::GraphQLApi":                                    AppSyncGraphQLApi,
 	"AWS::AppSync::GraphQLSchema":                                 AppSyncGraphQLSchema,
@@ -98,9 +108,12 @@ var mapping = map[string]ResourceType{
 	"AWS::Backup::BackupPlan":                                     BackupPlan,
 	"AWS::Backup::BackupSelection":                                BackupSelection,
 	"AWS::Backup::BackupVault":                                    BackupVault,
+	"AWS::Backup::Framework":                                      Unmapped,
+	"AWS::Backup::ReportPlan":                                     Unmapped,
 	"AWS::Batch::ComputeEnvironment":                              BatchComputeEnvironment,
 	"AWS::Batch::JobDefinition":                                   BatchJobDefinition,
 	"AWS::Batch::JobQueue":                                        BatchJobQueue,
+	"AWS::Batch::SchedulingPolicy":                                Unmapped,
 	"AWS::Budgets::Budget":                                        BudgetsBudget,
 	"AWS::Budgets::BudgetsAction":                                 Unmapped,
 	"AWS::CE::AnomalyMonitor":                                     Unmapped,
@@ -129,6 +142,7 @@ var mapping = map[string]ResourceType{
 	"AWS::CloudFront::KeyGroup":                                   CloudFrontKeyGroup,
 	"AWS::CloudFront::OriginRequestPolicy":                        CloudFrontOriginRequestPolicy,
 	"AWS::CloudFront::PublicKey":                                  CloudFrontPublicKey,
+	"AWS::CloudFront::ResponseHeadersPolicy":                      Unmapped,
 	"AWS::CloudFormation::PublicTypeVersion":                      Unmapped,
 	"AWS::CloudFormation::Publisher":                              Unmapped,
 	"AWS::CloudFormation::TypeActivation":                         Unmapped,
@@ -181,7 +195,12 @@ var mapping = map[string]ResourceType{
 	"AWS::Config::OrganizationConformancePack":                    ConfigOrganizationConformancePack,
 	"AWS::Config::RemediationConfiguration":                       ConfigRemediationConfiguration,
 	"AWS::Config::StoredQuery":                                    Unmapped,
+	"AWS::Connect::ContactFlow":                                   Unmapped,
+	"AWS::Connect::ContactFlowModule":                             Unmapped,
+	"AWS::Connect::HoursOfOperation":                              Unmapped,
 	"AWS::Connect::QuickConnect":                                  Unmapped,
+	"AWS::Connect::User":                                          Unmapped,
+	"AWS::Connect::UserHierarchyGroup":                            Unmapped,
 	"AWS::CustomerProfiles::Domain":                               Unmapped,
 	"AWS::CustomerProfiles::Integration":                          Unmapped,
 	"AWS::CustomerProfiles::ObjectType":                           Unmapped,
@@ -199,11 +218,13 @@ var mapping = map[string]ResourceType{
 	"AWS::DataBrew::Job":                                          Unmapped,
 	"AWS::DataBrew::Project":                                      Unmapped,
 	"AWS::DataBrew::Recipe":                                       Unmapped,
+	"AWS::DataBrew::Ruleset":                                      Unmapped,
 	"AWS::DataBrew::Schedule":                                     Unmapped,
 	"AWS::DataPipeline::Pipeline":                                 Unmapped,
 	"AWS::DataSync::Agent":                                        Unmapped,
 	"AWS::DataSync::LocationEFS":                                  Unmapped,
 	"AWS::DataSync::LocationFSxWindows":                           Unmapped,
+	"AWS::DataSync::LocationHDFS":                                 Unmapped,
 	"AWS::DataSync::LocationNFS":                                  Unmapped,
 	"AWS::DataSync::LocationObjectStorage":                        Unmapped,
 	"AWS::DataSync::LocationS3":                                   Unmapped,
@@ -222,6 +243,7 @@ var mapping = map[string]ResourceType{
 	"AWS::DynamoDB::Table":                                        DynamoDbTable,
 	"AWS::DynamoDB::GlobalTable":                                  Unmapped,
 	"AWS::EC2::CapacityReservation":                               Unmapped,
+	"AWS::EC2::CapacityReservationFleet":                          Unmapped,
 	"AWS::EC2::CarrierGateway":                                    Unmapped,
 	"AWS::EC2::ClientVpnAuthorizationRule":                        Unmapped,
 	"AWS::EC2::ClientVpnEndpoint":                                 Unmapped,
@@ -239,6 +261,10 @@ var mapping = map[string]ResourceType{
 	"AWS::EC2::Host":                                              Unmapped,
 	"AWS::EC2::Instance":                                          Ec2Instance,
 	"AWS::EC2::InternetGateway":                                   Ec2InternetGateway,
+	"AWS::EC2::IPAM":                                              Unmapped,
+	"AWS::EC2::IPAMAllocation":                                    Unmapped,
+	"AWS::EC2::IPAMPool":                                          Unmapped,
+	"AWS::EC2::IPAMScope":                                         Unmapped,
 	"AWS::EC2::LaunchTemplate":                                    Ec2LaunchTemplate,
 	"AWS::EC2::LocalGatewayRoute":                                 Unmapped,
 	"AWS::EC2::LocalGatewayRouteTableVPCAssociation":              Unmapped,
@@ -278,6 +304,7 @@ var mapping = map[string]ResourceType{
 	"AWS::EC2::TransitGatewayRouteTable":                          Ec2TransitGatewayRouteTable,
 	"AWS::EC2::TransitGatewayRouteTableAssociation":               Ec2TransitGatewayRouteTable,
 	"AWS::EC2::TransitGatewayRouteTablePropagation":               Ec2TransitGatewayRouteTable,
+	"AWS::EC2::TransitGatewayVpcAttachment":                       Unmapped,
 	"AWS::EC2::VPC":                                               Ec2Vpc,
 	"AWS::EC2::VPCCidrBlock":                                      Ec2Vpc,
 	"AWS::EC2::VPCDHCPOptionsAssociation":                         Ec2Vpc,
@@ -349,6 +376,10 @@ var mapping = map[string]ResourceType{
 	"AWS::EventSchemas::Registry":                                 Unmapped,
 	"AWS::EventSchemas::RegistryPolicy":                           Unmapped,
 	"AWS::EventSchemas::Schema":                                   Unmapped,
+	"AWS::Evidently::Experiment":                                  Unmapped,
+	"AWS::Evidently::Feature":                                     Unmapped,
+	"AWS::Evidently::Launch":                                      Unmapped,
+	"AWS::Evidently::Project":                                     Unmapped,
 	"AWS::FIS::ExperimentTemplate":                                Unmapped,
 	"AWS::FMS::NotificationChannel":                               Unmapped,
 	"AWS::FMS::Policy":                                            Unmapped,
@@ -414,6 +445,7 @@ var mapping = map[string]ResourceType{
 	"AWS::GuardDuty::Master":                                      Unmapped,
 	"AWS::GuardDuty::Member":                                      GuardDutyMember,
 	"AWS::GuardDuty::ThreatIntelSet":                              Unmapped,
+	"AWS::HealthLake::FHIRDatastore":                              Unmapped,
 	"AWS::IAM::AccessKey":                                         IamAccessKey,
 	"AWS::IAM::Group":                                             IamGroup,
 	"AWS::IAM::InstanceProfile":                                   IamInstanceProfile,
@@ -450,10 +482,14 @@ var mapping = map[string]ResourceType{
 	"AWS::IoT::CustomMetric":                                      Unmapped,
 	"AWS::IoT::Dimension":                                         Unmapped,
 	"AWS::IoT::DomainConfiguration":                               Unmapped,
+	"AWS::IoT::FleetMetric":                                       Unmapped,
+	"AWS::IoT::JobTemplate":                                       Unmapped,
+	"AWS::IoT::Logging":                                           Unmapped,
 	"AWS::IoT::MitigationAction":                                  Unmapped,
 	"AWS::IoT::Policy":                                            IoTPolicy,
 	"AWS::IoT::PolicyPrincipalAttachment":                         Unmapped,
 	"AWS::IoT::ProvisioningTemplate":                              Unmapped,
+	"AWS::IoT::ResourceSpecificLogging":                           Unmapped,
 	"AWS::IoT::ScheduledAudit":                                    Unmapped,
 	"AWS::IoT::SecurityProfile":                                   Unmapped,
 	"AWS::IoT::Thing":                                             IoTThing,
@@ -478,6 +514,8 @@ var mapping = map[string]ResourceType{
 	"AWS::IoTThingsGraph::FlowTemplate":                           Unmapped,
 	"AWS::IoTWireless::Destination":                               Unmapped,
 	"AWS::IoTWireless::DeviceProfile":                             Unmapped,
+	"AWS::IoTWireless::FuotaTask":                                 Unmapped,
+	"AWS::IoTWireless::MulticastGroup":                            Unmapped,
 	"AWS::IoTWireless::PartnerAccount":                            Unmapped,
 	"AWS::IoTWireless::ServiceProfile":                            Unmapped,
 	"AWS::IoTWireless::TaskDefinition":                            Unmapped,
@@ -511,8 +549,16 @@ var mapping = map[string]ResourceType{
 	"AWS::Lambda::LayerVersionPermission":                         Unmapped,
 	"AWS::Lambda::Permission":                                     Unnecessary,
 	"AWS::Lambda::Version":                                        LambdaVersion,
+	"AWS::Lex::Bot":                                               Unmapped,
+	"AWS::Lex::BotAlias":                                          Unmapped,
+	"AWS::Lex::BotVersion":                                        Unmapped,
+	"AWS::Lex::ResourcePolicy":                                    Unmapped,
 	"AWS::LicenseManager::Grant":                                  Unmapped,
 	"AWS::LicenseManager::License":                                Unmapped,
+	"AWS::Lightsail::Database":                                    Unmapped,
+	"AWS::Lightsail::Disk":                                        Unmapped,
+	"AWS::Lightsail::Instance":                                    Unmapped,
+	"AWS::Lightsail::StaticIp":                                    Unmapped,
 	"AWS::Location::GeofenceCollection":                           Unmapped,
 	"AWS::Location::Map":                                          Unmapped,
 	"AWS::Location::PlaceIndex":                                   Unmapped,
@@ -554,6 +600,11 @@ var mapping = map[string]ResourceType{
 	"AWS::MediaPackage::PackagingConfiguration":                   Unmapped,
 	"AWS::MediaPackage::PackagingGroup":                           Unmapped,
 	"AWS::MediaStore::Container":                                  Unmapped,
+	"AWS::MemoryDB::ACL":                                          Unmapped,
+	"AWS::MemoryDB::Cluster":                                      Unmapped,
+	"AWS::MemoryDB::ParameterGroup":                               Unmapped,
+	"AWS::MemoryDB::SubnetGroup":                                  Unmapped,
+	"AWS::MemoryDB::User":                                         Unmapped,
 	"AWS::Neptune::DBCluster":                                     NeptuneDbCluster,
 	"AWS::Neptune::DBClusterParameterGroup":                       NeptuneDbClusterParameterGroup,
 	"AWS::Neptune::DBInstance":                                    NeptuneDbInstance,
@@ -574,6 +625,7 @@ var mapping = map[string]ResourceType{
 	"AWS::NimbleStudio::StreamingImage":                           Unmapped,
 	"AWS::NimbleStudio::Studio":                                   Unmapped,
 	"AWS::NimbleStudio::StudioComponent":                          Unmapped,
+	"AWS::OpenSearchService::Domain":                              Unmapped,
 	"AWS::OpsWorks::App":                                          Unmapped,
 	"AWS::OpsWorks::ElasticLoadBalancerAttachment":                Unmapped,
 	"AWS::OpsWorks::Instance":                                     Unmapped,
@@ -582,6 +634,9 @@ var mapping = map[string]ResourceType{
 	"AWS::OpsWorks::UserProfile":                                  Unmapped,
 	"AWS::OpsWorks::Volume":                                       Unmapped,
 	"AWS::OpsWorksCM::Server":                                     Unmapped,
+	"AWS::Panorama::ApplicationInstance":                          Unmapped,
+	"AWS::Panorama::Package":                                      Unmapped,
+	"AWS::Panorama::PackageVersion":                               Unmapped,
 	"AWS::Pinpoint::ADMChannel":                                   Unmapped,
 	"AWS::Pinpoint::APNSChannel":                                  Unmapped,
 	"AWS::Pinpoint::APNSSandboxChannel":                           Unmapped,
@@ -595,6 +650,7 @@ var mapping = map[string]ResourceType{
 	"AWS::Pinpoint::EmailTemplate":                                Unmapped,
 	"AWS::Pinpoint::EventStream":                                  Unmapped,
 	"AWS::Pinpoint::GCMChannel":                                   Unmapped,
+	"AWS::Pinpoint::InAppTemplate":                                Unmapped,
 	"AWS::Pinpoint::PushTemplate":                                 Unmapped,
 	"AWS::Pinpoint::SMSChannel":                                   Unmapped,
 	"AWS::Pinpoint::SmsTemplate":                                  Unmapped,
@@ -626,11 +682,23 @@ var mapping = map[string]ResourceType{
 	"AWS::RDS::EventSubscription":                                 Unmapped,
 	"AWS::RDS::GlobalCluster":                                     Unmapped,
 	"AWS::RDS::OptionGroup":                                       Unmapped,
+	"AWS::RUM::AppMonitor":                                        Unmapped,
 	"AWS::Redshift::Cluster":                                      RedshiftCluster,
 	"AWS::Redshift::ClusterParameterGroup":                        RedshiftParameterGroup,
 	"AWS::Redshift::ClusterSecurityGroup":                         RedshiftSecurityGroup,
 	"AWS::Redshift::ClusterSecurityGroupIngress":                  Unmapped,
 	"AWS::Redshift::ClusterSubnetGroup":                           RedshiftSubnetGroup,
+	"AWS::Redshift::EndpointAccess":                               Unmapped,
+	"AWS::Redshift::EndpointAuthorization":                        Unmapped,
+	"AWS::Redshift::EventSubscription":                            Unmapped,
+	"AWS::Redshift::ScheduledAction":                              Unmapped,
+	"AWS::RefactorSpaces::Application":                            Unmapped,
+	"AWS::RefactorSpaces::Environment":                            Unmapped,
+	"AWS::RefactorSpaces::Route":                                  Unmapped,
+	"AWS::RefactorSpaces::Service":                                Unmapped,
+	"AWS::Rekognition::Project":                                   Unmapped,
+	"AWS::ResilienceHub::App":                                     Unmapped,
+	"AWS::ResilienceHub::ResiliencyPolicy":                        Unmapped,
 	"AWS::ResourceGroups::Group":                                  Unmapped,
 	"AWS::RoboMaker::Fleet":                                       Unmapped,
 	"AWS::RoboMaker::Robot":                                       Unmapped,
@@ -655,6 +723,7 @@ var mapping = map[string]ResourceType{
 	"AWS::Route53Resolver::FirewallDomainList":                    Unmapped,
 	"AWS::Route53Resolver::FirewallRuleGroup":                     Unmapped,
 	"AWS::Route53Resolver::FirewallRuleGroupAssociation":          Unmapped,
+	"AWS::Route53Resolver::ResolverConfig":                        Unmapped,
 	"AWS::Route53Resolver::ResolverDNSSECConfig":                  Unmapped,
 	"AWS::Route53Resolver::ResolverEndpoint":                      Unmapped,
 	"AWS::Route53Resolver::ResolverQueryLoggingConfig":            Unmapped,
@@ -664,6 +733,8 @@ var mapping = map[string]ResourceType{
 	"AWS::S3::AccessPoint":                                        Unmapped,
 	"AWS::S3::Bucket":                                             S3Bucket,
 	"AWS::S3::BucketPolicy":                                       S3Bucket,
+	"AWS::S3::MultiRegionAccessPoint":                             Unmapped,
+	"AWS::S3::MultiRegionAccessPointPolicy":                       Unmapped,
 	"AWS::S3::StorageLens":                                        Unmapped,
 	"AWS::S3ObjectLambda::AccessPoint":                            Unmapped,
 	"AWS::S3ObjectLambda::AccessPointPolicy":                      Unmapped,
@@ -759,9 +830,11 @@ var mapping = map[string]ResourceType{
 	"AWS::StepFunctions::StateMachine":                            StepFunctionStateMachine,
 	"AWS::Synthetics::Canary":                                     Unmapped,
 	"AWS::Timestream::Database":                                   Unmapped,
+	"AWS::Timestream::ScheduledQuery":                             Unmapped,
 	"AWS::Timestream::Table":                                      Unmapped,
 	"AWS::Transfer::Server":                                       TransferServer,
 	"AWS::Transfer::User":                                         TransferUser,
+	"AWS::Transfer::Workflow":                                     Unmapped,
 	"AWS::WAF::ByteMatchSet":                                      WafByteMatchSet,
 	"AWS::WAF::IPSet":                                             WafIpSet,
 	"AWS::WAF::Rule":                                              WafRule,
@@ -786,6 +859,9 @@ var mapping = map[string]ResourceType{
 	"AWS::WAFRegional::WebACL":                                    WafRegionalWebACL,
 	"AWS::WAFRegional::WebACLAssociation":                         WafRegionalWebACL,
 	"AWS::WAFRegional::XssMatchSet":                               WafRegionalXssMatchSet,
+	"AWS::Wisdom::Assistant":                                      Unmapped,
+	"AWS::Wisdom::AssistantAssociation":                           Unmapped,
+	"AWS::Wisdom::KnowledgeBase":                                  Unmapped,
 	"AWS::WorkSpaces::ConnectionAlias":                            Unmapped,
 	"AWS::WorkSpaces::Workspace":                                  WorkspacesWorkspace,
 	"AWS::XRay::Group":                                            Unmapped,
